package com.example.greenwatch;

import androidx.appcompat.app.AppCompatActivity;
import androidx.lifecycle.Observer;
import androidx.lifecycle.ViewModelProvider;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.example.greenwatch.models.Device;
import com.example.greenwatch.viewmodels.MainActivityViewModel;

import java.util.List;

public class MainActivity extends AppCompatActivity {

    private TextView tvstatusmessage;
    private Button audiodetectionButton;
    private Button videodetectionButton;
    private Button accelerometerButton;
    private Button audiodetectionAndAccelerometerButton;
    private Button videodetectionAndAccelerometerButton;
    private Button connectionButton;
    private MainActivityViewModel mMainActivityViewModel;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        tvstatusmessage = (TextView) findViewById(R.id.tvStatusmessage);
        audiodetectionButton = (Button) findViewById(R.id.audiodetectionButton);
        videodetectionButton = (Button) findViewById(R.id.videodetectionButton);
        accelerometerButton = (Button) findViewById(R.id.accelerometerButton);
        audiodetectionAndAccelerometerButton = (Button) findViewById(R.id.audiodetectionAndAccelerometerButton);
        videodetectionAndAccelerometerButton = (Button) findViewById(R.id.videodetectionAndAccelerometerButton);
        connectionButton = (Button) findViewById(R.id.connectionButton);

        mMainActivityViewModel = new ViewModelProvider(this).get(MainActivityViewModel.class);
        mMainActivityViewModel.init();
        mMainActivityViewModel.getConnectedDeviceList().observe(this, new Observer<List<Device>>() {
            @Override
            public void onChanged(List<Device> devices) {
                StringBuilder sb = new StringBuilder();
                sb.append("Time Stamp: ");
                sb.append(mMainActivityViewModel.getTimeStamp(mMainActivityViewModel.getLocalDeviceUUID()));
                sb.append(";\n");
                sb.append("DeviceID: ");
                sb.append(mMainActivityViewModel.getDeviceID(mMainActivityViewModel.getLocalDeviceUUID()));
                sb.append(";\n");
                sb.append("Sensor Status: ");
                sb.append(mMainActivityViewModel.getSensorStatus(mMainActivityViewModel.getLocalDeviceUUID()));
                sb.append(";\n");
                sb.append("Sensor Type: ");
                sb.append(mMainActivityViewModel.getSensorType(mMainActivityViewModel.getLocalDeviceUUID()));
                sb.append(";\n");
                sb.append("Sensor Massage: ");
                sb.append(mMainActivityViewModel.getSensorMassage(mMainActivityViewModel.getLocalDeviceUUID()));
                tvstatusmessage.setText(sb);
                Toast.makeText(MainActivity.this, "onChanged", Toast.LENGTH_LONG).show();
            }
        });

        audiodetectionButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //openAudiodetectionActivity();
                mMainActivityViewModel.setDevice(mMainActivityViewModel.getLocalDeviceUUID(), "10:51", "12345", false, "Audio", 10);
            }
        });
        videodetectionButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //openVideodetectionActivity();
                mMainActivityViewModel.setSensorType(mMainActivityViewModel.getLocalDeviceUUID(), "Video");
                mMainActivityViewModel.setTimeStamp(mMainActivityViewModel.getLocalDeviceUUID(), "12:50");
                mMainActivityViewModel.setDeviceID(mMainActivityViewModel.getLocalDeviceUUID(), mMainActivityViewModel.getLocalDeviceUUID());
            }
        });
        accelerometerButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openAccelerometerActivity();
                mMainActivityViewModel.setSensorType(mMainActivityViewModel.getLocalDeviceUUID(), "Accelerometer");
            }
        });
        audiodetectionAndAccelerometerButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                //openAudiodetectionAndAccelerometerActivity();
                mMainActivityViewModel.setSensorType(mMainActivityViewModel.getLocalDeviceUUID(), "AudiodetectionAndAccelerometer");
                mMainActivityViewModel.setTimeStamp(mMainActivityViewModel.getLocalDeviceUUID(), "00:00");
                mMainActivityViewModel.setDeviceID(mMainActivityViewModel.getLocalDeviceUUID(), "6789");
            }
        });
        videodetectionAndAccelerometerButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openVideodetectionAndAccelerometerActivity();
            }
        });
        connectionButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                openConnectionActivity();
            }
        });
    }
    public void openAudiodetectionActivity(){
        Intent intent = new Intent(this, AudiodetectionActivity.class);
        startActivity(intent);
    }
    public void openVideodetectionActivity(){
        Intent intent =  new Intent(this, VideodetectionActivity.class);
        startActivity(intent);
    }
    public void openAccelerometerActivity(){
        Intent intent = new Intent(this, AccelerometerActivity.class);
        startActivity(intent);
    }
    public void openAudiodetectionAndAccelerometerActivity(){
        Intent intent = new Intent(this, AudiodetectionAndAccelerometerActivity.class);
        startActivity(intent);
    }
    public void openVideodetectionAndAccelerometerActivity(){
        Intent intent = new Intent(this, VideodetectionAndAccelerometerActivity.class);
        startActivity(intent);
    }
    public void openConnectionActivity(){
        Intent intent = new Intent(this, ConnectionActivity.class);
        startActivity(intent);
    }

}