package com.example.greenwatch.viewmodels;

import androidx.lifecycle.LiveData;
import androidx.lifecycle.MutableLiveData;
import androidx.lifecycle.ViewModel;

import com.example.greenwatch.models.Device;
import com.example.greenwatch.repositories.DeviceRepository;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class AccelerometerViewModel extends ViewModel {

    private MutableLiveData<List<Device>> mDeviceList;
    private MutableLiveData<Boolean> mMovementDetected = new MutableLiveData<>();
    private DeviceRepository mDeviceRepository;
    private ArrayList<Float> Gesamt_be;
    int arraySize = 500;
    int functionCallCount;
    float meanValue;
    float offsetValue;
    float thresholdValue;
    boolean startMeasuring;

    public void init() {
        if (mDeviceList == null) {
            mDeviceRepository = DeviceRepository.getInstance();
            mDeviceList = mDeviceRepository.getConnectedDeviceList();
        }
        initGesamtBE();
        mMovementDetected.setValue(false);
        functionCallCount = 0;
        meanValue = 0f;
        offsetValue = 0.1f;
        thresholdValue = 0.15f;
        startMeasuring = false;
    }

    public void initGesamtBE() {
        Gesamt_be = new ArrayList<>(arraySize);
        for (int i = 0; i < arraySize; i++) {
            Gesamt_be.add(0f);
        }
    }

    public void addValueToGesamtBE(float newValue) {
        if (Gesamt_be.size() == arraySize) {
            Gesamt_be.remove(Gesamt_be.size() -1);
        }
        Gesamt_be.add(0, newValue);
        functionCallCount++;
    }

    public void meanValueCalculation() {
        for (float element : Gesamt_be) {
            meanValue += Math.abs(element);
        }
        meanValue = meanValue/arraySize;
    }

    public void calibrateAccelerometerSensor() {
        if (functionCallCount <= arraySize) {
            offsetValue = meanValue;
        }
        else {
            startMeasuring = true;
        }
    }

    public void checkAlarmCondition() {
        if (meanValue > (thresholdValue + offsetValue) && startMeasuring && !mMovementDetected.getValue()) {
            mMovementDetected.setValue(true);
        }
        else if (meanValue < (thresholdValue + offsetValue) && mMovementDetected.getValue()){
            mMovementDetected.setValue(false);
        }
    }

    public String getSystemTimeStamp() {
        SimpleDateFormat formatter = new SimpleDateFormat("HH:mm:ss");
        Date date = new Date(System.currentTimeMillis());
        return formatter.format(date);
    }

    public LiveData<Boolean> getMovementDetectedValue() {
        return mMovementDetected;
    }

    public LiveData<List<Device>> getConnectedDeviceList() {
        return mDeviceList;
    }

    public void setDevice(String deviceID, String timeStamp, String newDeviceID, boolean sensorStatus, String sensorType, int sensorMassage) {
        mDeviceRepository.setDevice(deviceID, timeStamp,newDeviceID, sensorStatus, sensorType, sensorMassage);
    }

    public void setTimeStamp(String deviceID, String timeStamp) {
        mDeviceRepository.setTimeStamp(deviceID, timeStamp);
    }

    public String getTimeStamp(String deviceID) {
        return mDeviceRepository.getTimeStamp(deviceID);
    }

    public void setDeviceID(String deviceID, String newDeviceID) {
        mDeviceRepository.setDeviceID(deviceID, newDeviceID);
    }

    public String getDeviceID(String deviceID) {
        return mDeviceRepository.getDeviceID(deviceID);
    }

    public void setSensorStatus(String deviceID, boolean sensorStatus) {
        mDeviceRepository.setSensorStatus(deviceID, sensorStatus);
    }

    public boolean getSensorStatus(String deviceID) {
        return mDeviceRepository.getSensorStatus(deviceID);
    }

    public void setSensorType(String deviceID, String sensorType) {
        mDeviceRepository.setSensorType(deviceID, sensorType);
    }

    public String getSensorType(String deviceID) {
        return mDeviceRepository.getSensorType(deviceID);
    }

    public void setSensorMassage(String deviceID, int sensorMessage) {
        mDeviceRepository.setSensorMassage(deviceID, sensorMessage);
    }

    public int getSensorMassage(String deviceID) {
        return mDeviceRepository.getSensorMassage(deviceID);
    }

    public String getLocalDeviceUUID() {
        return mDeviceRepository.getLocalDeviceUUID();
    }
}
